@@ -23,9 +23,6 @@
 #include "spvm_use.h"
 #include "spvm_basic_type.h"
 #include "spvm_my.h"
-#include "spvm_string_buffer.h"
-#include "spvm_sub.h"
-#include "spvm_package.h"
 
 SPVM_OP* SPVM_TOKE_newOP(SPVM_COMPILER* compiler, int32_t type) {
   
@@ -43,41 +40,19 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
   // Constant minus sign
   int32_t minus = 0;
   
-  // Expect sub name
-  int32_t expect_sub_name = compiler->expect_sub_name;
+  // Expect name
+  _Bool expect_sub_name = compiler->expect_sub_name;
   compiler->expect_sub_name = 0;
   
-  // Before token is arrow
-  int32_t before_token_is_arrow = compiler->before_token_is_arrow;
-  compiler->before_token_is_arrow = 0;
-
-  // Expect field name
-  int32_t expect_field_name = compiler->expect_field_name;
-  compiler->expect_field_name = 0;
-  
-  // Expect variable expansion state
-  int32_t state_var_expansion = compiler->state_var_expansion;
-  compiler->state_var_expansion = SPVM_TOKE_C_STATE_VAR_EXPANSION_DEFAULT;
-  
   while(1) {
     // Get current character
     char ch = *compiler->bufptr;
     
-    // Variable expansion state
-    if (state_var_expansion == SPVM_TOKE_C_STATE_VAR_EXPANSION_FIRST_CONCAT) {
-      ch = '.';
-    }
-    else if (state_var_expansion == SPVM_TOKE_C_STATE_VAR_EXPANSION_SECOND_CONCAT) {
-      ch = '.';
-    }
-    else if (state_var_expansion == SPVM_TOKE_C_STATE_VAR_EXPANSION_DOUBLE_QUOTE) {
-      ch = '"';
-    }
-    
     // line end
     switch (ch) {
-      case '\0': {
+      case '\0':
         compiler->cur_file = NULL;
+        free(compiler->cur_src);
         compiler->cur_src = NULL;
         compiler->bufptr = NULL;
         compiler->befbufptr = NULL;
@@ -86,20 +61,22 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
         SPVM_LIST* op_use_stack = compiler->op_use_stack;
         
         while (1) {
-          if (op_use_stack->length == 0) {
-            return 0;
-          }
-          else if (op_use_stack->length > 0) {
-            SPVM_OP* op_use = SPVM_LIST_shift(op_use_stack);
+          if (op_use_stack->length > 0) {
+            SPVM_OP* op_use = SPVM_LIST_pop(op_use_stack);
             
+            assert(op_use->uv.use->op_type);
+            assert(op_use->uv.use->op_type->uv.type->dimension == 0);
             const char* package_name = op_use->uv.use->op_type->uv.type->basic_type->name;
             
+            assert(package_name);
+            
             SPVM_PACKAGE* found_package = SPVM_HASH_fetch(compiler->package_symtable, package_name, strlen(package_name));
             
             if (found_package) {
               continue;
             }
             else {
+              
               // change :: to / and add ".spvm"
               int32_t module_path_base_length = (int32_t)(strlen(package_name) + 6);
               char* module_path_base = SPVM_COMPILER_ALLOCATOR_safe_malloc_zero(compiler, module_path_base_length + 1);
@@ -146,19 +123,7 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
                 }
               }
               if (!fh) {
-                if (op_use->uv.use->is_require) {
-                  op_use->uv.use->load_fail = 1;
-                  SPVM_OP* op_package = SPVM_OP_new_op(compiler, SPVM_OP_C_ID_PACKAGE, op_use->file, op_use->line);
-                  SPVM_TYPE* type = SPVM_TYPE_new(compiler);
-                  type->basic_type = op_use->uv.use->op_type->uv.type->basic_type;
-                  SPVM_OP* op_type = SPVM_OP_new_op_type(compiler, type, op_use->file, op_use->line);
-                  type->basic_type->fail_load = 1;
-                  
-                  SPVM_OP_build_package(compiler, op_package, op_type, NULL, NULL);
-                  
-                  continue;
-                }
-                else {
+                if (op_use) {
                   fprintf(stderr, "Can't locate %s in @INC (@INC contains:", module_path_base);
                   {
                     int32_t i;
@@ -167,10 +132,12 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
                       fprintf(stderr, " %s", include_path);
                     }
                   }
-                  fprintf(stderr, ") at %s line %d\n", op_use->file, op_use->line);
-                  compiler->error_count++;
-                  return 0;
+                  fprintf(stderr, ") at %s line %" PRId32 "\n", op_use->file, op_use->line);
                 }
+                else {
+                  fprintf(stderr, "Can't find file %s\n", cur_file);
+                }
+                exit(EXIT_FAILURE);
               }
               
               compiler->cur_file = cur_file;
@@ -179,14 +146,19 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
               fseek(fh, 0, SEEK_END);
               int32_t file_size = (int32_t)ftell(fh);
               if (file_size < 0) {
-                SPVM_COMPILER_error(compiler, "Can't read file %s at %s line %d\n", cur_file, op_use->file, op_use->line);
-                return 0;
+                fprintf(stderr, "Can't read file %s at %s line %" PRId32 "\n", cur_file, op_use->file, op_use->line);
+                exit(EXIT_FAILURE);
               }
               fseek(fh, 0, SEEK_SET);
-              char* cur_src = SPVM_COMPILER_ALLOCATOR_safe_malloc_zero(compiler, file_size + 1);
+              char* cur_src = SPVM_UTIL_ALLOCATOR_safe_malloc_zero(file_size + 1);
               if ((int32_t)fread(cur_src, 1, file_size, fh) < file_size) {
-                SPVM_COMPILER_error(compiler, "Can't read file %s at %s line %d\n", cur_file, op_use->file, op_use->line);
-                return 0;
+                if (op_use) {
+                  fprintf(stderr, "Can't read file %s at %s line %" PRId32 "\n", cur_file, op_use->file, op_use->line);
+                }
+                else {
+                  fprintf(stderr, "Can't read file %s\n", cur_file);
+                }
+                exit(EXIT_FAILURE);
               }
               fclose(fh);
               cur_src[file_size] = '\0';
@@ -197,9 +169,10 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
               compiler->cur_line = 1;
               break;
             }
+            
           }
           else {
-            assert(0);
+            return 0;
           }
         }
         if (compiler->cur_src) {
@@ -208,52 +181,38 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
         else {
           return 0;
         }
-      }
-      // Skip space character
+      
+      /* Skip space character */
       case ' ':
       case '\t':
       case '\r':
         compiler->bufptr++;
         continue;
+
       case '\n':
         compiler->bufptr++;
         compiler->cur_line++;
+        
         continue;
-      // Cancat
-      case '.': {
-        if (state_var_expansion == SPVM_TOKE_C_STATE_VAR_EXPANSION_FIRST_CONCAT) {
-          compiler->state_var_expansion = SPVM_TOKE_C_STATE_VAR_EXPANSION_VAR;
-          yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_CONCAT);
-          return '.';
-        }
-        else if (state_var_expansion == SPVM_TOKE_C_STATE_VAR_EXPANSION_SECOND_CONCAT) {
-          compiler->state_var_expansion = SPVM_TOKE_C_STATE_VAR_EXPANSION_DOUBLE_QUOTE;
-          yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_CONCAT);
-          return '.';
+      
+      /* Cancat */
+      case '.':
+        compiler->bufptr++;
+        if (*compiler->bufptr == '=') {
+          compiler->bufptr++;
+          SPVM_OP* op_special_assign = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_SPECIAL_ASSIGN);
+          op_special_assign->flag = SPVM_OP_C_FLAG_SPECIAL_ASSIGN_CONCAT;
+          
+          yylvalp->opval = op_special_assign;
+          
+          return SPECIAL_ASSIGN;
         }
         else {
-          compiler->bufptr++;
-          if (*compiler->bufptr == '=') {
-            compiler->bufptr++;
-            SPVM_OP* op_special_assign = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_SPECIAL_ASSIGN);
-            op_special_assign->flag = SPVM_OP_C_FLAG_SPECIAL_ASSIGN_CONCAT;
-            
-            yylvalp->opval = op_special_assign;
-            
-            return SPECIAL_ASSIGN;
-          }
-          else if (*compiler->bufptr == '.' && *(compiler->bufptr + 1) == '.') {
-            compiler->bufptr += 2;
-            yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_DOT3);
-            return DOT3;
-          }
-          else {
-            yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_CONCAT);
-            return '.';
-          }
+          yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_CONCAT);
+          return '.';
         }
-      }
-      // Addition
+      
+      /* Addition */
       case '+':
         compiler->bufptr++;
         
@@ -276,7 +235,7 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
           return '+';
         }
       
-      // Subtract
+      /* Subtract */
       case '-':
         compiler->bufptr++;
         
@@ -296,7 +255,6 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
           compiler->bufptr++;
           yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_NULL);
           compiler->expect_sub_name = 1;
-          compiler->before_token_is_arrow = 1;
           
           return ARROW;
         }
@@ -318,7 +276,7 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
           yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_NULL);;
           return '-';
         }
-      // Multiply
+      /* Multiply */
       case '*': {
         compiler->bufptr++;
         
@@ -337,7 +295,7 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
           return MULTIPLY;
         }
       }
-      // Divide
+      /* Divide */
       case '/': {
         compiler->bufptr++;
         
@@ -392,7 +350,7 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
       }
       case '|':
         compiler->bufptr++;
-        // Or
+        /* Or */
         if (*compiler->bufptr == '|') {
           compiler->bufptr++;
           SPVM_OP* op = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_OR);
@@ -416,7 +374,7 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
 
       case '&':
         compiler->bufptr++;
-        // Or
+        /* Or */
         if (*compiler->bufptr == '&') {
           compiler->bufptr++;
           SPVM_OP* op = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_AND);
@@ -432,14 +390,14 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
           
           return SPECIAL_ASSIGN;
         }
-        // AMPERSAND - Bit and or type reference
+        /* AMPERSAND - Bit and or type reference*/
         else {
           SPVM_OP* op = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_BIT_AND);
           yylvalp->opval = op;
           return AMPERSAND;
         }
       
-      // Comment
+      /* Comment */
       case '#':
         compiler->bufptr++;
         while(1) {
@@ -486,21 +444,14 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
         else {
           compiler->bufptr++;
           
-          // ==
+          /* == */
           if (*compiler->bufptr == '=') {
             compiler->bufptr++;
             SPVM_OP* op = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_EQ);
             yylvalp->opval = op;
             return REL;
           }
-          // =>
-          if (*compiler->bufptr == '>') {
-            compiler->bufptr++;
-            SPVM_OP* op = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_NULL);
-            yylvalp->opval = op;
-            return ',';
-          }
-          // =
+          /* = */
           else {
             SPVM_OP* op = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_ASSIGN);
             yylvalp->opval = op;
@@ -537,7 +488,7 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
           yylvalp->opval = op;
           return REL;
         }
-        // <
+        /* < */
         else {
           compiler->bufptr++;
           SPVM_OP* op = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_LT);
@@ -588,14 +539,14 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
             }
           }
         }
-        // >=
+        /* >= */
         else if (*compiler->bufptr == '=') {
           compiler->bufptr++;
           SPVM_OP* op = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_GE);
           yylvalp->opval = op;
           return REL;
         }
-        // >
+        /* > */
         else {
           compiler->bufptr++;
           SPVM_OP* op = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_GT);
@@ -626,7 +577,7 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
       case '\'': {
         compiler->bufptr++;
         
-        char ch;
+        int8_t ch;
         // Null string
         if (*compiler->bufptr == '\'') {
           ch = '\0';
@@ -636,7 +587,19 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
         else {
           if (*compiler->bufptr == '\\') {
             compiler->bufptr++;
-            if (*compiler->bufptr == 'r') {
+            if (*compiler->bufptr == '"') {
+              ch = '"';
+              compiler->bufptr++;
+            }
+            else if (*compiler->bufptr == '\'') {
+              ch = '\'';
+              compiler->bufptr++;
+            }
+            else if (*compiler->bufptr == '\\') {
+              ch = '\\';
+              compiler->bufptr++;
+            }
+            else if (*compiler->bufptr == 'r') {
               ch = 0x0D;
               compiler->bufptr++;
             }
@@ -656,13 +619,9 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
               ch = '\f';
               compiler->bufptr++;
             }
-            else if (*compiler->bufptr == '0') {
-              ch = '\0';
-              compiler->bufptr++;
-            }
             else {
-              ch = *compiler->bufptr;
-              compiler->bufptr++;
+              fprintf(stderr, "Invalid escape character \"%c%c\" at %s line %" PRId32 "\n", *(compiler->bufptr -1),*compiler->bufptr, compiler->cur_file, compiler->cur_line);
+              exit(EXIT_FAILURE);
             }
           }
           else {
@@ -670,12 +629,11 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
             compiler->bufptr++;
           }
           
-          if (*compiler->bufptr == '\'') {
-            compiler->bufptr++;
-          }
-          else {
-            SPVM_COMPILER_error(compiler, "Can't find constant char terminator \"'\" at %s line %d\n", compiler->cur_file, compiler->cur_line);
+          if (*compiler->bufptr != '\'') {
+            fprintf(stderr, "syntax error: character literal don't finish with '\n");
+            exit(EXIT_FAILURE);
           }
+          compiler->bufptr++;
         }
         
         // Constant 
@@ -686,23 +644,11 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
         return CONSTANT;
       }
       case '"': {
-        if (state_var_expansion == SPVM_TOKE_C_STATE_VAR_EXPANSION_DOUBLE_QUOTE) {
-          // $var-> is invalid
-          if (*compiler->bufptr == '-' && *(compiler->bufptr + 1) == '>') {
-            SPVM_COMPILER_error(compiler, "Don't support variable expansion of array access or field access at %s line %d\n", compiler->cur_file, compiler->cur_line);
-          }
-        }
-        else {
-          compiler->bufptr++;
-        }
-
-        compiler->state_var_expansion = SPVM_TOKE_C_STATE_VAR_EXPANSION_DEFAULT;
+        compiler->bufptr++;
         
-        // Save current position
+        /* Save current position */
         const char* cur_token_ptr = compiler->bufptr;
         
-        int8_t next_state_var_expansion = SPVM_TOKE_C_STATE_VAR_EXPANSION_DEFAULT;
-        
         char* str;
         int32_t str_length = 0;
         if (*(compiler->bufptr) == '"') {
@@ -711,17 +657,12 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
           compiler->bufptr++;
         }
         else {
-          int32_t finish = 0;
+          _Bool finish = 0;
           while(1) {
             // End of string literal
             if (*compiler->bufptr == '"' && *(compiler->bufptr - 1) != '\\') {
               finish = 1;
             }
-            // Variable expansion
-            else if (*compiler->bufptr == '$' && *(compiler->bufptr - 1) != '\\') {
-              finish = 1;
-              next_state_var_expansion = SPVM_TOKE_C_STATE_VAR_EXPANSION_FIRST_CONCAT;
-            }
             // End of source file
             else if (*compiler->bufptr == '\0') {
               finish = 1;
@@ -734,8 +675,8 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
             }
           }
           if (*compiler->bufptr == '\0') {
-            SPVM_COMPILER_error(compiler, "Can't find string terminator '\"' anywhere before EOF at %s line %d\n", compiler->cur_file, compiler->cur_line);
-            continue;
+            fprintf(stderr, "syntax error: string don't finish with '\"'\n");
+            exit(EXIT_FAILURE);
           }
           
           int32_t str_tmp_len = (int32_t)(compiler->bufptr - cur_token_ptr);
@@ -748,28 +689,46 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
             while (char_ptr != compiler->bufptr - 1) {
               if (*char_ptr == '\\') {
                 char_ptr++;
-                if (*char_ptr == 'r') {
+                if (*char_ptr == '"') {
+                  str[str_length] = '"';
+                  str_length++;
+                }
+                else if (*char_ptr == '\'') {
+                  str[str_length] = '\'';
+                  str_length++;
+                }
+                else if (*char_ptr == '\\') {
+                  str[str_length] = '\\';
+                  str_length++;
+                }
+                else if (*char_ptr == 'r') {
                   str[str_length] = 0x0D;
+                  str_length++;
                 }
                 else if (*char_ptr == 'n') {
                   str[str_length] = 0x0A;
+                  str_length++;
                 }
                 else if (*char_ptr == 't') {
                   str[str_length] = '\t';
+                  str_length++;
                 }
                 else if (*char_ptr == 'b') {
                   str[str_length] = '\b';
+                  str_length++;
                 }
                 else if (*char_ptr == 'f') {
                   str[str_length] = '\f';
+                  str_length++;
                 }
                 else if (*char_ptr == '0') {
                   str[str_length] = '\0';
+                  str_length++;
                 }
                 else {
-                  str[str_length] = *char_ptr;
+                  fprintf(stderr, "Invalid escape character \"%c%c\" at %s line %" PRId32 "\n", *(compiler->bufptr -1),*compiler->bufptr, compiler->cur_file, compiler->cur_line);
+                  exit(EXIT_FAILURE);
                 }
-                str_length++;
               }
               else {
                 str[str_length] = *char_ptr;
@@ -785,101 +744,55 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
         
         yylvalp->opval = op_constant;
         
-        // Next is start from $
-        if (next_state_var_expansion == SPVM_TOKE_C_STATE_VAR_EXPANSION_FIRST_CONCAT) {
-          compiler->state_var_expansion = next_state_var_expansion;
-          compiler->bufptr--;
-        }
-        
         return CONSTANT;
       }
       case '\\':
         compiler->bufptr++;
         return REF;
       default:
-        // Variable
+        /* Variable */
         if (ch == '$') {
-          // Derefernece
-          if (*(compiler->bufptr + 1) == '$') {
-            compiler->bufptr++;
+          /* Save current position */
+          const char* cur_token_ptr = compiler->bufptr;
+          
+          compiler->bufptr++;
+          
+          // Var name
+          while (
+            isalnum(*compiler->bufptr)
+            || (*compiler->bufptr) == '_'
+            || (*compiler->bufptr == ':' && *(compiler->bufptr + 1) == ':')
+            || (*compiler->bufptr) == '@'
+          )
+          {
+            if ((*compiler->bufptr == ':' && *(compiler->bufptr + 1) == ':')) {
+              compiler->bufptr += 2;
+            }
+            else {
+              compiler->bufptr++;
+            }
+          }
+          
+          // Deference
+          if (cur_token_ptr == compiler->bufptr - 1) {
             SPVM_OP* op = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_DEREF);
             yylvalp->opval = op;
             return DEREF;
           }
-          // Exception variable
-          else if (*(compiler->bufptr + 1) == '@') {
-            compiler->bufptr += 2;
-            SPVM_OP* op_exception_var = SPVM_OP_new_op(compiler, SPVM_OP_C_ID_EXCEPTION_VAR, compiler->cur_file, compiler->cur_line);
-            yylvalp->opval = op_exception_var;
-            return EXCEPTION_VAR;
-          }
-          // Lexical variable or Package variable
-          else {
-            compiler->bufptr++;
-
-            int8_t have_brace = 0;
-            
-            if (*compiler->bufptr == '{') {
-              have_brace = 1;
-              compiler->bufptr++;
-            }
-            
-            // Save current position
-            const char* cur_token_ptr = compiler->bufptr;
-            
-            // Var name
-            while (
-              isalnum(*compiler->bufptr)
-              || (*compiler->bufptr) == '_'
-              || (*compiler->bufptr == ':' && *(compiler->bufptr + 1) == ':')
-              || (*compiler->bufptr) == '@'
-            )
-            {
-              if ((*compiler->bufptr == ':' && *(compiler->bufptr + 1) == ':')) {
-                compiler->bufptr += 2;
-              }
-              else {
-                compiler->bufptr++;
-              }
-            }
           
+          int32_t str_len = (compiler->bufptr - cur_token_ptr);
+          char* var_name = SPVM_COMPILER_ALLOCATOR_safe_malloc_zero(compiler, str_len + 1);
+          memcpy(var_name, cur_token_ptr, str_len);
+          var_name[str_len] = '\0';
 
-            int32_t var_name_length_without_sigil = compiler->bufptr - cur_token_ptr;
-            char* var_name = SPVM_COMPILER_ALLOCATOR_safe_malloc_zero(compiler, 1 + var_name_length_without_sigil + 1);
-            var_name[0] = '$';
-            memcpy(&var_name[1], cur_token_ptr, var_name_length_without_sigil);
-            var_name[1 + var_name_length_without_sigil] = '\0';
-            
-            if (have_brace) {
-              if (*compiler->bufptr == '}') {
-                compiler->bufptr++;
-              }
-              else {
-                SPVM_COMPILER_error(compiler, "Need close brace at end of variable at %s line %d\n", compiler->cur_file, compiler->cur_line);
-              }
-            }
+          // Name OP
+          SPVM_OP* op_name = SPVM_OP_new_op_name(compiler, var_name, compiler->cur_file, compiler->cur_line);
 
-            // Name OP
-            SPVM_OP* op_name = SPVM_OP_new_op_name(compiler, var_name, compiler->cur_file, compiler->cur_line);
-
-            yylvalp->opval = op_name;
-            
-            // Variable expansion next state is double quote
-            if (state_var_expansion == SPVM_TOKE_C_STATE_VAR_EXPANSION_VAR) {
-              compiler->state_var_expansion = SPVM_TOKE_C_STATE_VAR_EXPANSION_SECOND_CONCAT;
-            }
-            
-            // Package variable
-            if (isupper(var_name[1]) || strstr(var_name, "::")) {
-              return PACKAGE_VAR_NAME;
-            }
-            // Lexical variable
-            else {
-              return VAR_NAME;
-            }
-          }
+          yylvalp->opval = op_name;
+          
+          return VAR_NAME;
         }
-        // Number literal
+        /* Number literal */
         else if (isdigit(ch)) {
           const char* cur_token_ptr;
           
@@ -912,7 +825,7 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
             digit = 10;
           }
           
-          int32_t is_floating_number = 0;
+          _Bool is_floating_number = 0;
           
           compiler->bufptr++;
           // Scan number
@@ -954,7 +867,7 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
           
           // Number literal(first is space for sign)
           int32_t str_len = (compiler->bufptr - cur_token_ptr);
-          char* num_str = (char*)SPVM_COMPILER_ALLOCATOR_safe_malloc_zero(compiler, str_len + 2);
+          char* num_str = (char*) SPVM_UTIL_ALLOCATOR_safe_malloc_zero(str_len + 2);
           {
             int32_t i;
             int32_t pos = 0;
@@ -1005,7 +918,8 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
             double num = strtod(num_str, &end);
             
             if (*end != '\0') {
-              SPVM_COMPILER_error(compiler, "Invalid float literal at %s line %d\n", compiler->cur_file, compiler->cur_line);
+              fprintf(stderr, "Invalid float literal %s at %s line %" PRId32 "\n", num_str, compiler->cur_file, compiler->cur_line);
+              exit(EXIT_FAILURE);
             }
             op_constant = SPVM_OP_new_op_constant_float(compiler, (float)num, compiler->cur_file, compiler->cur_line);
           }
@@ -1014,7 +928,8 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
             double num = strtod(num_str, &end);
             
             if (*end != '\0') {
-              SPVM_COMPILER_error(compiler, "Invalid double literal at %s line %d\n", compiler->cur_file, compiler->cur_line);
+              fprintf(stderr, "Invalid double literal %s at %s line %" PRId32 "\n", num_str, compiler->cur_file, compiler->cur_line);
+              exit(EXIT_FAILURE);
             }
             op_constant = SPVM_OP_new_op_constant_double(compiler, num, compiler->cur_file, compiler->cur_line);
           }
@@ -1022,8 +937,8 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
           else if (constant_type->basic_type->id == SPVM_BASIC_TYPE_C_ID_INT) {
             int64_t num;
             errno = 0;
-            int32_t out_of_range = 0;
-            int32_t invalid = 0;
+            _Bool out_of_range = 0;
+            _Bool invalid = 0;
             
             if (digit == 16 || digit == 8 || digit == 2) {
               uint64_t unum = (uint64_t)strtoull(num_str, &end, digit);
@@ -1046,10 +961,12 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
             }
             
             if (invalid) {
-              SPVM_COMPILER_error(compiler, "Invalid int literal at %s line %d\n", compiler->cur_file, compiler->cur_line);
+              fprintf(stderr, "Invalid int literal %s at %s line %" PRId32 "\n", num_str, compiler->cur_file, compiler->cur_line);
+              exit(EXIT_FAILURE);
             }
             else if (out_of_range) {
-              SPVM_COMPILER_error(compiler, "int literal out of range at %s line %d\n", compiler->cur_file, compiler->cur_line);
+              fprintf(stderr, "int literal out of range %s at %s line %" PRId32 "\n", num_str, compiler->cur_file, compiler->cur_line);
+              exit(EXIT_FAILURE);
             }
             op_constant = SPVM_OP_new_op_constant_int(compiler, num, compiler->cur_file, compiler->cur_line);
           }
@@ -1057,8 +974,8 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
           else if (constant_type->basic_type->id == SPVM_BASIC_TYPE_C_ID_LONG) {
             int64_t num;
             errno = 0;
-            int32_t out_of_range = 0;
-            int32_t invalid = 0;
+            _Bool out_of_range = 0;
+            _Bool invalid = 0;
             
             if (digit == 16 || digit == 8 || digit == 2) {
               uint64_t unum = (uint64_t)strtoull(num_str, &end, digit);
@@ -1081,10 +998,12 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
             }
             
             if (invalid) {
-              SPVM_COMPILER_error(compiler, "Invalid long literal at %s line %d\n", compiler->cur_file, compiler->cur_line);
+              fprintf(stderr, "Invalid long literal %s at %s line %" PRId32 "\n", num_str, compiler->cur_file, compiler->cur_line);
+              exit(EXIT_FAILURE);
             }
             else if (out_of_range) {
-              SPVM_COMPILER_error(compiler, "long literal out of range at %s line %d\n", compiler->cur_file, compiler->cur_line);
+              fprintf(stderr, "long literal out of range %s at %s line %" PRId32 "\n", num_str, compiler->cur_file, compiler->cur_line);
+              exit(EXIT_FAILURE);
             }
             op_constant = SPVM_OP_new_op_constant_long(compiler, num, compiler->cur_file, compiler->cur_line);
           }
@@ -1130,13 +1049,7 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
             SPVM_HASH_insert(compiler->name_symtable, keyword, str_len, keyword);
           }
           
-          if (expect_sub_name) {
-            SPVM_LIST_push(compiler->current_sub_names, keyword);
-          }
-          else if (expect_field_name) {
-            // None
-          }
-          else {
+          if (!expect_sub_name) {
             switch (keyword[0]) {
               // Keyword
               case 'b' :
@@ -1145,12 +1058,6 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
                   return BYTE;
                 }
                 break;
-              case 'B' :
-                if (strcmp(keyword, "BEGIN") == 0) {
-                  yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_BEGIN);
-                  return BEGIN;
-                }
-                break;
               case 'c' :
                 if (strcmp(keyword, "case") == 0) {
                   yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_CASE);
@@ -1160,6 +1067,10 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
                   yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_CROAK);
                   return CROAK;
                 }
+                else if (strcmp(keyword, "const") == 0) {
+                  yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_CONST);
+                  return CONST;
+                }
                 break;
               case 'd' :
                 if (strcmp(keyword, "default") == 0) {
@@ -1216,7 +1127,6 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
               case 'h' :
                 if (strcmp(keyword, "has") == 0) {
                   yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_FIELD);
-                  compiler->expect_field_name = 1;
                   return HAS;
                 }
                 break;
@@ -1245,10 +1155,6 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
                   yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_LAST);
                   return LAST;
                 }
-                else if (strcmp(keyword, "length") == 0) {
-                  yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_STRING_LENGTH);
-                  return LENGTH;
-                }
                 else if (strcmp(keyword, "lt") == 0) {
                   SPVM_OP* op = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_STRING_LT);
                   yylvalp->opval = op;
@@ -1298,7 +1204,10 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
                   yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_PACKAGE_VAR);
                   return OUR;
                 }
-                else if (strcmp(keyword, "object") == 0) {
+                
+                break;
+              case 'O' :
+                if (strcmp(keyword, "object") == 0) {
                   yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_OBJECT);
                   return OBJECT;
                 }
@@ -1328,8 +1237,8 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
                   
                   return DESCRIPTOR;
                 }
-                else if (strcmp(keyword, "pointer_t") == 0) {
-                  SPVM_OP* op_descriptor = SPVM_OP_new_op_descriptor(compiler, SPVM_DESCRIPTOR_C_ID_POINTER_T, compiler->cur_file, compiler->cur_line);
+                else if (strcmp(keyword, "pointer") == 0) {
+                  SPVM_OP* op_descriptor = SPVM_OP_new_op_descriptor(compiler, SPVM_DESCRIPTOR_C_ID_POINTER, compiler->cur_file, compiler->cur_line);
                   yylvalp->opval = op_descriptor;
                   
                   return DESCRIPTOR;
@@ -1340,20 +1249,6 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
                   yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_RETURN);
                   return RETURN;
                 }
-                else if (strcmp(keyword, "require") == 0) {
-                  yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_REQUIRE);
-                  return REQUIRE;
-                }
-                else if (strcmp(keyword, "rw") == 0) {
-                  SPVM_OP* op_descriptor = SPVM_OP_new_op_descriptor(compiler, SPVM_DESCRIPTOR_C_ID_RW, compiler->cur_file, compiler->cur_line);
-                  yylvalp->opval = op_descriptor;
-                  return DESCRIPTOR;
-                }
-                else if (strcmp(keyword, "ro") == 0) {
-                  SPVM_OP* op_descriptor = SPVM_OP_new_op_descriptor(compiler, SPVM_DESCRIPTOR_C_ID_RO, compiler->cur_file, compiler->cur_line);
-                  yylvalp->opval = op_descriptor;
-                  return DESCRIPTOR;
-                }
                 break;
               case 's' :
                 if (strcmp(keyword, "self") == 0) {
@@ -1391,10 +1286,6 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
                   yylvalp->opval = SPVM_OP_new_op_undef(compiler, compiler->cur_file, compiler->cur_line);
                   return UNDEF;
                 }
-                else if (strcmp(keyword, "unless") == 0) {
-                  yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_UNLESS);
-                  return UNLESS;
-                }
                 else if (strcmp(keyword, "use") == 0) {
                   yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_USE);
                   return USE;
@@ -1420,11 +1311,6 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
                   yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_WEAKEN);
                   return WEAKEN;
                 }
-                else if (strcmp(keyword, "wo") == 0) {
-                  SPVM_OP* op_descriptor = SPVM_OP_new_op_descriptor(compiler, SPVM_DESCRIPTOR_C_ID_WO, compiler->cur_file, compiler->cur_line);
-                  yylvalp->opval = op_descriptor;
-                  return DESCRIPTOR;
-                }
                 break;
               case '_':
                 if (strcmp(keyword, "__END__") == 0) {
@@ -1437,7 +1323,8 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
           
           // Symbol name can't conatain __
           if (strstr(keyword, "__")) {
-            SPVM_COMPILER_error(compiler, "Symbol name can't contain __ at %s line %d\n", compiler->cur_file, compiler->cur_line);
+            fprintf(stderr, "Symbol name can't contain __ at %s line %" PRId32 "\n", compiler->cur_file, compiler->cur_line);
+            exit(1);
           }
           
           SPVM_OP* op_name = SPVM_OP_new_op_name(compiler, keyword, compiler->cur_file, compiler->cur_line);
@@ -1446,15 +1333,10 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
           return NAME;
         }
         
-        // Return character
+        /* Return character */
         compiler->bufptr++;
         yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_NULL);
         
-        // Expect field name
-        if (before_token_is_arrow && ch == '{') {
-          compiler->expect_field_name = 1;
-        }
-        
         return (int) (uint8_t) ch;
     }
   }
